// In this example, we have a generic setValue method.
// It allows to set a value for any of the member fields of the Parameters class.
// Abstraction is often good, but in this case, there is too much abstraction
// - the method now needs unnecessary error handling and it's relatively easy to
// accidentally call it with a wrong "name" string, a typo is enough to cause a bug.
// Splitting it into separate methods would be better.
public class Parameters {
    private int height;
    private int width;
    private int depth;

    // If you select the line with "height = value",
    // you can right-click, choose refactor -> extract -> method,
    // give the new method a name, like setHeight, and hit "Refactor".
    // This will extract the meaningful behaviour from this setValue method.
    // Repeat for width and depth, and then you can get rid of setValue altogether.
    public void setValue(String name, int value) {
        if (name.equals("height")) {
            height = value;
            return;
        }
        if (name.equals("width")) {
            width = value;
            return;
        }
        if (name.equals("depth")) {
            depth = value;
            return;
        }
        // this should never be reached
        assert(false);
    }
}
